"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("core-js/modules/web.dom.iterable");

var _react = _interopRequireWildcard(require("react"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class Collapse extends _react.PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      height: 0
    };
    this.containerRef = null;
  }

  componentDidMount() {
    const transitionDuration = this.props.transitionDuration;

    if (this.props.open && this.containerRef) {
      this.setState({
        height: this.containerRef.clientHeight
      }, () => {
        // Once the animation is complete, set the height to auto
        // This ensures that if the content height changes, the parent height
        // adjust automatically
        setTimeout(() => {
          this.setState({
            height: "auto"
          });
        }, parseInt(transitionDuration, 10) * 1000);
      });
    }
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.open !== this.props.open && this.containerRef) {
      if (nextProps.open) {
        this.setState({
          height: this.containerRef.scrollHeight
        }, () => {
          setTimeout(() => {
            this.setState({
              height: "auto"
            });
          }, 200);
        });
      } else {
        // this is a case where the component is going from open to close state
        // When it's open, we set the height of container to 'auto'
        // But browers don't know how to transition from 'auto' to zero value
        // So we first set the height to the current height of content
        // And then set it to zero
        this.setState({
          height: this.containerRef.clientHeight
        }, () => {
          // Directly calling setState with height 0 does not work
          // Even though the render method is called with the changed height and
          // height 0 twice. --\O/--
          // weirdly, i couldn't get it to work consistently with a setTimeout of 0 or even
          // 1. It would work sometimes and not at other times. So i said, ok, i will
          // wait for 20ms before it animates
          setTimeout(() => {
            this.setState({
              height: 0
            });
          }, 20);
        });
      }
    }
  }

  render() {
    const _this$props = this.props,
          id = _this$props.id,
          open = _this$props.open,
          children = _this$props.children,
          style = _this$props.style,
          transitionDuration = _this$props.transitionDuration,
          transitionType = _this$props.transitionType;
    const height = this.state.height;
    return _react.default.createElement("div", {
      style: _objectSpread({
        overflow: "hidden",
        transition: `height ${transitionDuration} ${transitionType}`,
        height
      }, style),
      ref: node => this.containerRef = node,
      id: id,
      "aria-hidden": !open
    }, children);
  }

}

exports.default = Collapse;
Collapse.defaultProps = {
  transitionDuration: "0.3s",
  transitionType: "ease-in"
};